@@ -6,6 +6,7 @@ Main application window
 """
 
 from __future__ import unicode_literals
+import itertools
 from gi.repository import Gtk, Gio, Gdk, GLib, GdkPixbuf
 from syncthing_gtk.tools import _
 from syncthing_gtk.tools import (
@@ -38,9 +39,9 @@ import os, webbrowser, sys, time, logging, shutil, re
 log = logging.getLogger("App")
 
 # Internal version used by updater (if enabled)
-INTERNAL_VERSION		= "v0.9.4"
+INTERNAL_VERSION		= "v0.9.4.2"
 # Minimal Syncthing version supported by App
-MIN_ST_VERSION			= "0.14.48"
+MIN_ST_VERSION			= "0.14.50"
 
 COLOR_DEVICE			= "#707070"					# Dark-gray
 COLOR_DEVICE_SYNCING	= "#2A89C8"					# Blue
@@ -48,7 +49,7 @@ COLOR_DEVICE_CONNECTED	= "#2AAB61"					# Green
 COLOR_DEVICE_OFFLINE	= COLOR_DEVICE				# Dark-gray
 COLOR_DEVICE_ERROR		= "#87000B"					# Red
 COLOR_OWN_DEVICE		= "#C0C0C0"					# Light-gray
-COLOR_FOLDER			= "#9246B1"					# Dark-purbple
+COLOR_FOLDER			= "#9246B1"					# Dark-purple
 COLOR_FOLDER_SYNCING	= COLOR_DEVICE_SYNCING		# Blue
 COLOR_FOLDER_SCANNING	= COLOR_DEVICE_SYNCING		# Blue
 COLOR_FOLDER_IDLE		= COLOR_DEVICE_CONNECTED	# Green
@@ -58,16 +59,17 @@ COLOR_NEW				= COLOR_OWN_DEVICE			# Light-gray
 SI_FRAMES				= 12 # Number of animation frames for status icon
 
 # Response IDs
-RESPONSE_RESTART		= 256
-RESPONSE_FIX_FOLDER_ID	= 257
-RESPONSE_FIX_NEW_DEVICE	= 258
-RESPONSE_FIX_IGNORE		= 259
-RESPONSE_QUIT			= 260
-RESPONSE_START_DAEMON	= 271
-RESPONSE_SLAIN_DAEMON	= 272
-RESPONSE_SPARE_DAEMON	= 273
-RESPONSE_UR_ALLOW		= 274
-RESPONSE_UR_FORBID		= 275
+RESPONSE_RESTART			= 256
+RESPONSE_FIX_ADD_FOLDER		= 257
+RESPONSE_FIX_IGNORE_FOLDER	= 258
+RESPONSE_FIX_ADD_DEVICE		= 259
+RESPONSE_FIX_IGNORE_DEV		= 260
+RESPONSE_QUIT				= 261
+RESPONSE_START_DAEMON		= 271
+RESPONSE_SLAIN_DAEMON		= 272
+RESPONSE_SPARE_DAEMON		= 273
+RESPONSE_UR_ALLOW			= 274
+RESPONSE_UR_FORBID			= 275
 
 # RI's
 REFRESH_INTERVAL_DEFAULT	= 1
@@ -113,21 +115,21 @@ class App(Gtk.Application, TimerManager):
 		self.use_headerbar = (
 			not IS_UNITY and (not self.config["use_old_header"] or IS_GNOME)
 			and (Gtk.get_major_version(), Gtk.get_minor_version()) >= (3, 10) )
-		
+
 		self.daemon = None	# Created by setup_connection method
 		# If enabled (by -o argument), daemon output is captured and printed
 		# to stdout
 		self.dump_daemon_output = None
 		self.notifications = None
-		# connect_dialog may be displayed durring initial communication
+		# connect_dialog may be displayed during initial communication
 		# or if daemon shuts down.
 		self.connect_dialog = None
-		# Used when upgrading from incompatibile version
+		# Used when upgrading from incompatible version
 		self.restart_after_update = None
 		self.dark_color = None			# RGBA. None by default, changes with dark themes
 		self.recv_limit = -1			# Used mainly to prevent menu handlers from recursing
 		self.send_limit = -1			# -//-
-		self.ur_question_shown = False	# Used to prevent showing 'Do you wan't usage reporting'
+		self.ur_question_shown = False	# Used to prevent showing 'Do you want usage reporting'
 										# question more than once until ST-GTK is restarted.
 		self.home_dir_override = None	# If set by '--home'
 		self.wizard = None
@@ -140,6 +142,9 @@ class App(Gtk.Application, TimerManager):
 		self.devices_never_loaded = True
 		self.folders_never_loaded = True
 		self.sync_animation = 0
+
+		self.editor_device = None
+		self.editor_folder = None
 	
 	
 	def do_startup(self, *a):
@@ -195,16 +200,16 @@ class App(Gtk.Application, TimerManager):
 		else:
 			# Fallback for old GTK without option parsing
 			if "-h" in sys.argv or "--help" in sys.argv:
-				print "Usage:"
-				print "  %s [arguments]" % (sys.argv[0],)
-				print "Arguments:"
+				sys.stdout.write("Usage:\n")
+				sys.stdout.write("  %s [arguments]\n" % (sys.argv[0],))
+				sys.stdout.write("Arguments:\n")
 				for o in self.arguments:
 					# Don't display hidden and unsupported parameters
 					if not o.long_name in ("force-update", "quit"):
-						print "  -%s, --%s %s" % (
+						sys.stdout.write("  -%s, --%s %s\n" % (
 							chr(o.short_name),
 							o.long_name.ljust(10),
-							o.description)
+							o.description))
 				sys.exit(0)
 			def is_option(name):
 				# Emulating Gtk.Application.do_local_options
@@ -363,7 +368,7 @@ class App(Gtk.Application, TimerManager):
 				self.daemon = Daemon(os.path.join(self.home_dir_override, "config.xml"))
 			else:
 				self.daemon = Daemon()
-		except InvalidConfigurationException, e:
+		except InvalidConfigurationException as e:
 			# Syncthing is not configured, most likely never launched.
 			# Run wizard.
 			if IS_XP:
@@ -374,7 +379,7 @@ class App(Gtk.Application, TimerManager):
 			self.hide()
 			self.show_wizard()
 			return False
-		except TLSErrorException, e:
+		except TLSErrorException as e:
 			# This is pretty-much fatal. Display error message and bail out.
 			self.cb_syncthing_con_error(self.daemon, Daemon.UNKNOWN, str(e), e)
 			return False
@@ -426,7 +431,7 @@ class App(Gtk.Application, TimerManager):
 	def start_daemon_ui(self):
 		"""
 		Does same thing as start_daemon.
-		Additionaly displays 'Starting Daemon' message and swaps
+		Additionally displays 'Starting Daemon' message and swaps
 		menu items in notification icon menu.
 		"""
 		# Swap menu items in notification menu
@@ -502,7 +507,7 @@ class App(Gtk.Application, TimerManager):
 		if self.process == None:
 			# Upgrading if executable is not launched by Syncthing-GTK
 			# may fail in too many ways.
-			log.warning("Skiping updatecheck: Daemon not launched by me")
+			log.warning("Skipping updatecheck: Daemon not launched by me")
 			return
 		if self.force_update_version is None:
 			if (datetime.now() - self.config["last_updatecheck"]).total_seconds() < UPDATE_CHECK_INTERVAL:
@@ -622,20 +627,20 @@ class App(Gtk.Application, TimerManager):
 		# Move old from way
 		try:
 			shutil.move(bin, old_bin)
-		except Exception, e:
+		except Exception as e:
 			log.warning("Failed to upgrade daemon binary: Failed to rename old binary")
 			log.warning(e)
 			return
 		# Place new
 		try:
 			shutil.move(new_bin, bin)
-		except Exception, e:
+		except Exception as e:
 			log.warning("Failed to upgrade daemon binary: Failed to rename new binary")
 			log.warning(e)
 			# Return old back to place
 			try:
 				shutil.move(old_bin, bin)
-			except Exception, e:
+			except Exception as e:
 				# This really shouldn't happen, in more than one sense
 				log.error("Failed to upgrade daemon binary: Failed to rename backup")
 				log.exception(e)
@@ -643,9 +648,9 @@ class App(Gtk.Application, TimerManager):
 		# Remove old
 		try:
 			os.unlink(old_bin)
-		except Exception, e:
+		except Exception as e:
 			# Not exactly fatal
-			log.warning("Failed to remove backup binary durring backup")
+			log.warning("Failed to remove backup binary during backup")
 			log.warning(e)
 	
 	def cb_syncthing_connected(self, *a):
@@ -707,7 +712,7 @@ class App(Gtk.Application, TimerManager):
 						# ... unless he already decided once forever ...
 						self.display_connect_dialog(_("Waiting for Syncthing daemon at %s...") % (self.daemon.get_webui_url(),))
 					elif self.config["autostart_daemon"] == 1:
-						# ... or already gave persmission ...
+						# ... or already gave permission ...
 						self.display_connect_dialog(_("Starting Syncthing daemon"))
 						self.start_daemon()
 					else:
@@ -716,7 +721,7 @@ class App(Gtk.Application, TimerManager):
 		elif reason == Daemon.OLD_VERSION and self.config["st_autoupdate"] and not self.process is None and not StDownloader is None:
 			# Daemon is too old, but autoupdater is enabled and I have control of deamon.
 			# Try to update.
-			from configuration import LONG_AGO
+			from .configuration import LONG_AGO
 			self.config["last_updatecheck"] = LONG_AGO
 			self.restart_after_update = True
 			self.close_connect_dialog()
@@ -823,7 +828,7 @@ class App(Gtk.Application, TimerManager):
 		# Daemon argument is not used
 		RE_IP_PORT = re.compile(r"([0-9]+\.[0-9]+\.[0-9]+\.[0-9]+):([0-9]+)")
 		if "remote device speaks an older version of the protocol" in message:
-			# This one needs special treatement because remote port changes
+			# This one needs special treatment because remote port changes
 			# every time when this is reported.
 			id = re.search("to ([-0-9A-Za-z]+)", message)
 			version = re.search("protocol \(([^\)]+)\)", message)
@@ -885,7 +890,8 @@ class App(Gtk.Application, TimerManager):
 		r = RIBar("", Gtk.MessageType.WARNING,)
 		r.get_label().set_markup(markup)
 		if can_fix:
-			r.add_button(RIBar.build_button(_("_Add")), RESPONSE_FIX_FOLDER_ID)
+			r.add_button(RIBar.build_button(_("_Ignore")), RESPONSE_FIX_IGNORE_FOLDER)
+			r.add_button(RIBar.build_button(_("_Add")), RESPONSE_FIX_ADD_FOLDER)
 		self.show_error_box(r, {"nid" : nid, "rid" : rid, "label" : label } )
 	
 	def cb_syncthing_device_rejected(self, daemon, nid, name, address):
@@ -907,8 +913,8 @@ class App(Gtk.Application, TimerManager):
 			}
 		r = RIBar("", Gtk.MessageType.WARNING,)
 		r.get_label().set_markup(markup)
-		r.add_button(RIBar.build_button(_("_Add")), RESPONSE_FIX_NEW_DEVICE)
-		r.add_button(RIBar.build_button(_("_Ignore")), RESPONSE_FIX_IGNORE)
+		r.add_button(RIBar.build_button(_("_Add")), RESPONSE_FIX_ADD_DEVICE)
+		r.add_button(RIBar.build_button(_("_Ignore")), RESPONSE_FIX_IGNORE_DEV)
 		self.show_error_box(r, {"nid" : nid, "name" : name, "address" : address} )
 	
 	def cb_syncthing_my_id_changed(self, daemon, device_id):
@@ -1204,7 +1210,7 @@ class App(Gtk.Application, TimerManager):
 	
 	def get_folder_n_path(self, path):
 		"""
-		Returns tuple of ID of folder containign specified path and
+		Returns tuple of ID of folder containing specified path and
 		relative path in that folder, or (None, None) if specified path
 		doesn't belongs anywhere
 		"""
@@ -1231,7 +1237,7 @@ class App(Gtk.Application, TimerManager):
 		return self.builder.get_object(name) != None
 	
 	def hilight(self, boxes):
-		to_hilight = set([])
+		to_hilight = set()
 		for box in boxes:
 			if box["id"] in self.folders:
 				for d in box["devices"]:
@@ -1243,7 +1249,7 @@ class App(Gtk.Application, TimerManager):
 					if box in f["devices"]:
 						to_hilight.add(f)
 				to_hilight.add(box)
-		for box in [] + self.devices.values() + self.folders.values():
+		for box in itertools.chain(self.devices.values(), self.folders.values()):
 			box.set_hilight(box in to_hilight)
 	
 	def is_visible(self):
@@ -1320,7 +1326,7 @@ class App(Gtk.Application, TimerManager):
 					c.set_markup(message)
 					return True
 			return False
-		log.verbose("Settinig connect_dialog label %s" % message[0:15])
+		log.verbose("Setting connect_dialog label %s" % message[0:15])
 		set_label(self.connect_dialog.get_content_area(), message)
 	
 	def display_run_daemon_dialog(self):
@@ -1369,7 +1375,7 @@ class App(Gtk.Application, TimerManager):
 					self["window"].move(x, y)
 				GLib.idle_add(move_back)
 	
-	def show_folder(self, id, label, path, is_master, ignore_perms, rescan_interval, fswatcher_enabled, shared):
+	def show_folder(self, id, label, path, folder_type, ignore_perms, rescan_interval, fswatcher_enabled, shared):
 		""" Shared is expected to be list """
 		display_path = path
 		if IS_WINDOWS:
@@ -1388,17 +1394,17 @@ class App(Gtk.Application, TimerManager):
 			# Create new box
 			box = InfoBox(self, title, Gtk.Image.new_from_icon_name("drive-harddisk", Gtk.IconSize.LARGE_TOOLBAR))
 			# Add visible lines
-			box.add_value("id",			"version.svg",	_("Folder ID"),			id)
-			box.add_value("path",		"folder.svg",	_("Path"))
-			box.add_value("global",		"global.svg",	_("Global State"),		"? items, ?B")
-			box.add_value("local",		"home.svg",		_("Local State"),		"? items, ?B")
-			box.add_value("oos",		"dl_rate.svg",	_("Out Of Sync"),		"? items, ?B")
-			box.add_value("master",		"lock.svg",		_("Folder Type"))
-			box.add_value("ignore",		"ignore.svg",	_("Ignore Permissions"))
-			box.add_value("rescan",		"rescan.svg",	_("Rescan Interval"))
-			box.add_value("shared",		"shared.svg",	_("Shared With"))
+			box.add_value("id",				"version.svg",	_("Folder ID"),			id)
+			box.add_value("path",			"folder.svg",	_("Path"))
+			box.add_value("global",			"global.svg",	_("Global State"),		"? items, ?B")
+			box.add_value("local",			"home.svg",		_("Local State"),		"? items, ?B")
+			box.add_value("oos",			"dl_rate.svg",	_("Out Of Sync"),		"? items, ?B")
+			box.add_value("folder_type",	"lock.svg",		_("Folder Type"))
+			box.add_value("ignore",			"ignore.svg",	_("Ignore Permissions"))
+			box.add_value("rescan",			"rescan.svg",	_("Rescan Interval"))
+			box.add_value("shared",			"shared.svg",	_("Shared With"))
 			# Add hidden stuff
-			box.add_hidden_value("b_master", is_master)
+			box.add_hidden_value("b_master", folder_type)
 			box.add_hidden_value("can_override", False)
 			box.add_hidden_value("devices", shared)
 			box.add_hidden_value("norm_path", os.path.abspath(os.path.expanduser(path)))
@@ -1421,15 +1427,20 @@ class App(Gtk.Application, TimerManager):
 		# Set values
 		box.set_value("id",		id)
 		box.set_value("path",	display_path)
-		box.set_value("master",	_("Send Only") if is_master else _("Send & Receive"))
+		box.add_hidden_value("b_master", False)
+		if folder_type == "receiveonly":
+			box.set_value("folder_type",	_("Receive Only"))
+		elif folder_type == "sendonly":
+			box.set_value("b_master", True)
+			box.set_value("folder_type",	_("Send Only"))
+		else:
+			box.set_value("folder_type",	_("Send & Receive"))
 		box.set_value("ignore",	_("Yes") if ignore_perms else _("No"))
 		box.set_value("rescan",	"%s s%s" % (
 			rescan_interval, " " + _("(watch)") if fswatcher_enabled else "" ))
 		box.set_value("shared",	", ".join([ n.get_title() for n in shared ]))
-		box.set_value("b_master", is_master)
 		box.set_value("can_override", False)
 		box.set_visible("id",		self.config["folder_as_path"] or label not in (None, ""))
-		box.set_visible("master",	is_master)
 		box.set_visible("ignore",	ignore_perms)
 		return box
 	
@@ -1524,11 +1535,11 @@ class App(Gtk.Application, TimerManager):
 	def change_setting_async(self, setting_name, value, retry_on_error=False, restart=True):
 		"""
 		Asynchronously changes one value in daemon configuration and
-		optionaly restarts daemon.
+		optionally restarts daemon.
 		
 		This will:
 		 - call daemon.read_config() to read configuration from daemon
-		 - change value in recieved YAML document
+		 - change value in received YAML document
 		 - call daemon.write_config() to post configuration back
 		 - call daemon.restart()
 		Everthing will be done asynchronously and will be repeated
@@ -1569,7 +1580,7 @@ class App(Gtk.Application, TimerManager):
 		def csnr_config_read(config, setting_name, value, retry_on_error):
 			"""
 			Handler for change_setting_async
-			Modifies recieved config and post it back.
+			Modifies received config and post it back.
 			"""
 			c, setting = config, setting_name
 			while "/" in setting:
@@ -1597,6 +1608,13 @@ class App(Gtk.Application, TimerManager):
 		# Call
 		self.daemon.read_config(csnr_config_read, csnr_error, setting_name, value, retry_on_error)
 	
+	def add_ignored(self, ignore_type, value):
+		def cb(target, trash):
+			if ignore_type not in target:
+				target[ignore_type] = []
+			target[ignore_type].append(value)
+		self.change_setting_async(ignore_type, cb, restart=False)
+	
 	def quit(self, *a):
 		if self.process != None:
 			if IS_WINDOWS:
@@ -1628,7 +1646,7 @@ class App(Gtk.Application, TimerManager):
 	def show_add_folder_dialog(self, path=None):
 		"""
 		Waits for daemon to connect and shows 'add folder' dialog,
-		optionaly with pre-filled path entry.
+		optionally with pre-filled path entry.
 		"""
 		handler_id = None
 		def have_config(*a):
@@ -1648,7 +1666,7 @@ class App(Gtk.Application, TimerManager):
 	
 	def show_remove_folder_dialog(self, path):
 		"""
-		Waits for daemon to connect, then searchs for folder id assigned
+		Waits for daemon to connect, then searches for folder id assigned
 		with specified path and shows 'remove folder' dialog, it such
 		id is found.
 		If id is not found, does nothing.
@@ -1743,9 +1761,7 @@ class App(Gtk.Application, TimerManager):
 	
 	def cb_menu_add_device(self, event, *a):
 		""" Handler for 'Add device' menu item """
-		e = DeviceEditorDialog(self, True)
-		e.load()
-		e.show(self["window"])
+		self.open_editor_device()
 	
 	def cb_menu_daemon_settings(self, event, *a):
 		""" Handler for 'Daemon Settings' menu item """
@@ -1833,7 +1849,7 @@ class App(Gtk.Application, TimerManager):
 	def cb_menu_popup_edit_device(self, *a):
 		""" Handler for other 'edit' context menu item """
 		# Editing device
-		self.open_editor(DeviceEditorDialog, self.rightclick_box["id"])
+		self.open_editor_device(self.rightclick_box["id"])
 	
 	def cb_menu_popup_browse_folder(self, *a):
 		""" Handler for 'browse' folder context menu item """
@@ -1922,6 +1938,41 @@ class App(Gtk.Application, TimerManager):
 		e = cls(self, False, id)
 		e.load()
 		e.show(self["window"])
+
+	def open_editor_device(self, id=None, name=None):
+		# Close a previously opened deviceeditor
+		if self.editor_device:
+			self.editor_device.close()
+
+		self.editor_device = DeviceEditorDialog(self, id not in self.devices, id)
+
+		if name and id not in self.devices:
+			self.editor_device.call_after_loaded(self.editor_device["vname"].set_text, name)
+		self.editor_device.load()
+		self.editor_device.show(self["window"])
+
+	def open_editor_folder(self, id=None, label=None, nid=None):
+		# Close a previously opened deviceeditor
+		if self.editor_folder:
+			self.editor_folder.close()
+
+		self.editor_folder = FolderEditorDialog(self, id not in self.folders, id)
+
+		# Find folder with matching ID ...
+		if id in self.folders:
+			# ... if found, show edit dialog and pre-select
+			# matching device
+			self.editor_folder.call_after_loaded(self.editor_folder.mark_device, nid)
+		else:
+			# If there is no matching folder, prefill 'new folder'
+			# dialog and let user to save it
+			self.editor_folder.call_after_loaded(self.editor_folder.mark_device, nid)
+			self.editor_folder.call_after_loaded(self.editor_folder.fill_folder_id, id)
+			if label:
+				self.editor_folder.call_after_loaded(self.editor_folder["vlabel"].set_text, label)
+
+		self.editor_folder.load()
+		self.editor_folder.show(self["window"])
 	
 	def cb_menu_popup_show_id(self, *a):
 		""" Handler for 'show id' context menu item """
@@ -1984,40 +2035,18 @@ class App(Gtk.Application, TimerManager):
 		if response_id == RESPONSE_RESTART:
 			# Restart
 			self.daemon.restart()
-		elif response_id == RESPONSE_FIX_FOLDER_ID:
+		elif response_id == RESPONSE_FIX_ADD_FOLDER:
 			# Give up if there is no device with matching ID
 			if additional_data["nid"] in self.devices:
-				# Find folder with matching ID ...
-				if additional_data["rid"] in self.folders:
-					# ... if found, show edit dialog and pre-select
-					# matching device
-					e = FolderEditorDialog(self, False, additional_data["rid"])
-					e.call_after_loaded(e.mark_device, additional_data["nid"])
-					e.load()
-					e.show(self["window"])
-				else:
-					# If there is no matching folder, prefill 'new folder'
-					# dialog and let user to save it
-					e = FolderEditorDialog(self, True, additional_data["rid"])
-					e.call_after_loaded(e.mark_device, additional_data["nid"])
-					e.call_after_loaded(e.fill_folder_id, additional_data["rid"])
-					if additional_data["label"]:
-						e.call_after_loaded(e["vlabel"].set_text, additional_data["label"])
-					e.load()
-					e.show(self["window"])
-		elif response_id == RESPONSE_FIX_NEW_DEVICE:
-			e = DeviceEditorDialog(self, True, additional_data["nid"])
-			if additional_data["name"]:
-				e.call_after_loaded(e["vname"].set_text, additional_data["name"])
-			e.load()
-			e.show(self["window"])
-		elif response_id == RESPONSE_FIX_IGNORE:
+				self.open_editor_folder(additional_data['rid'], additional_data['label'], additional_data['nid'])
+		elif response_id == RESPONSE_FIX_IGNORE_FOLDER:
+			# Ignore unknown folder
+			self.add_ignored("ignoredFolders", additional_data['rid'])
+		elif response_id == RESPONSE_FIX_ADD_DEVICE:
+			self.open_editor_device(additional_data['nid'], additional_data['name'])
+		elif response_id == RESPONSE_FIX_IGNORE_DEV:
 			# Ignore unknown device
-			def add_ignored(target, trash):
-				if not "ignoredDevices" in target:
-					target["ignoredDevices"] = []
-				target["ignoredDevices"].append(additional_data["nid"])
-			self.change_setting_async("ignoredDevices", add_ignored, restart=False)
+			self.add_ignored("ignoredDevices", additional_data['nid'])
 		elif response_id == RESPONSE_UR_ALLOW:
 			# Allow Usage reporting
 			self.change_setting_async("options/urAccepted", 1)
@@ -2071,7 +2100,9 @@ class App(Gtk.Application, TimerManager):
 	
 	
 	def cb_daemon_line_captured(self, daemon, line):
-		print line
+		sys.stdout.write(line)
+		sys.stdout.write("\n")
+		sys.stdout.flush()
 	
 	
 	def cb_daemon_exit(self, proc, error_code):
@@ -2117,7 +2148,7 @@ class App(Gtk.Application, TimerManager):
 			d.load()
 			d.set_transient_for(self["window"] if self.connect_dialog is None
 					else self.connect_dialog)
-			# If binary exists, assume that something is completly wrong,
+			# If binary exists, assume that something is completely wrong,
 			# and change error message
 			if os.path.exists(self.config["syncthing_binary"]):
 				d.set_message("%s\n%s %s\n\n%s" % (
