@@ -55,8 +55,8 @@ if IS_WINDOWS:
 	import wmi, _winreg
 
 """ Localization lambdas """
-_ = lambda(a): _uc(gettext.gettext(a))
-_uc = lambda(b): b if type(b) == unicode else b.decode("utf-8")
+_ = lambda a: _uc(gettext.gettext(a))
+_uc = lambda b: b if type(b) == unicode else b.decode("utf-8")
 
 def luhn_b32generate(s):
 	"""
@@ -71,7 +71,7 @@ def luhn_b32generate(s):
 			raise ValueError("Digit %s is not valid" % (c,))
 		addend = factor * codepoint
 		factor = 1 if factor == 2 else 2
-		addend = (addend / n) + (addend % n)
+		addend = (addend // n) + (addend % n)
 		sum += addend
 	remainder = sum % n
 	checkcodepoint = (n - remainder) % n
@@ -91,7 +91,7 @@ def check_device_id(nid):
 			p = nid[i*14:((i+1)*14)-1]
 			try:
 				l = luhn_b32generate(p)
-			except Exception, e:
+			except Exception as e:
 				log.exception(e)
 				return False
 			g = "%s%s" % (p, l)
@@ -185,7 +185,7 @@ def parse_config_arguments(lst):
 
 def delta_to_string(d):
 	"""
-	Returns aproximate, human-readable and potentialy localized
+	Returns approximate, human-readable and potentially localized
 	string from specified timedelta object
 	"""
 	# Negative time, 'some time ago'
@@ -365,7 +365,7 @@ def get_config_dir():
 		return os.environ["XDG_CONFIG_HOME"]
 	if IS_WINDOWS and not IS_XP:
 		try:
-			import windows
+			from . import windows
 			return windows.get_unicode_home()
 		except Exception:
 			pass
@@ -449,17 +449,18 @@ def is_ran_on_startup(program_name):
 		# Check if desktop file is not marked as hidden
 		# (stupid way, but should work)
 		is_entry = False
-		for line in file(desktopfile, "r").readlines():
-			line = line.strip(" \r\t\n").lower()
-			if line == "[desktop entry]":
-				is_entry = True
-				continue
-			if "=" in line:
-				key, value = line.split("=", 1)
-				if key.strip(" ") == "hidden":
-					if value.strip(" ") == "true":
-						# Desktop file is 'hidden', i.e. disabled
-						return False
+		with open(desktopfile, "r") as f:
+			for line in f.readlines():
+				line = line.strip(" \r\t\n").lower()
+				if line == "[desktop entry]":
+					is_entry = True
+					continue
+				if "=" in line:
+					key, value = line.split("=", 1)
+					if key.strip(" ") == "hidden":
+						if value.strip(" ") == "true":
+							# Desktop file is 'hidden', i.e. disabled
+							return False
 		# File is present and not hidden - autostart is enabled
 		return is_entry
 
@@ -495,9 +496,10 @@ def set_run_on_startup(enabled, program_name, executable, icon="", description="
 				# Already exists
 				pass
 			try:
-				file(desktopfile, "w").write((DESKTOP_FILE % (
-					program_name, executable, icon, description)).encode('utf-8'))
-			except Exception, e:
+				with open(desktopfile, "w") as f:
+					desktop_contents = DESKTOP_FILE % (program_name, executable, icon, description)
+					f.write(desktop_contents.encode('utf-8'))
+			except Exception as e:
 				# IO errors or out of disk space... Not really
 				# expected, but may happen
 				log.warning("Failed to create autostart entry: %s", e)
@@ -506,7 +508,7 @@ def set_run_on_startup(enabled, program_name, executable, icon="", description="
 			try:
 				if os.path.exists(desktopfile):
 					os.unlink(desktopfile)
-			except Exception, e:
+			except Exception as e:
 				# IO or access error
 				log.warning("Failed to remove autostart entry: %s", e)
 				return False
@@ -516,25 +518,25 @@ def can_upgrade_binary(binary_path):
 	"""
 	Returns True if binary seems to be writable and placed in writable
 	directory. Result may be wrong on Windows, but it's still more
-	accurate that os.access, that respondes with complete fabulation --
+	accurate that os.access, that responds with complete fabulation --
 	https://mail.python.org/pipermail/python-list/2011-May/604395.html
 	"""
 	if IS_WINDOWS:
 		# Try to open file in same directory. It's not good idea trying
 		# to open very same file as Windows throws IOError if file is
-		# already open somewhere else (i.e. it's binary that is runing)
+		# already open somewhere else (i.e. it's binary that is running)
 		try:
 			path = binary_path + ".new"
 			if os.path.exists(path):
-				f = file(path, "r+b")
+				f = open(path, "r+b")
 				f.close()
 			else:
-				f = file(path, "wb")
+				f = open(path, "wb")
 				f.close()
 				os.unlink(path)
 			# return Maybe
 			return True
-		except Exception, e:
+		except Exception as e:
 			log.exception(e)
 			return False
 	else:
